@@ -22,6 +22,7 @@
 """
 Urwid tour.  Shows many of the standard widget types and features.
 """
+import sys
 
 import urwid
 import urwid.raw_display
@@ -311,6 +312,15 @@ class Renderer:
             urwid.Pile([urwid.Text(x) for x in quote.value]), left=4, right=4
         )
 
+    def render_Admonition(self, adm):
+        return urwid.Padding(
+            urwid.LineBox(
+                urwid.Pile([self.render(c) for c in adm.children]),
+                title=f"{adm.kind} : {adm.title}",
+                title_align="left",
+            ),
+        )
+
     def render_BlockDirective(self, directive):
         if directive.directive_name == "note":
             return urwid.Padding(
@@ -326,7 +336,7 @@ class Renderer:
             inner = directive.inner
             content = " ".join(directive.args0)
             if content:
-                assert not inner
+                assert not inner, (directive.args0, inner)
             else:
                 assert len(inner.children) == 1
 
@@ -385,8 +395,10 @@ class Renderer:
             return urwid.Text("EMPTY")
 
         try:
-            rr = [self.render(o) for o in paragraph.children]
-            return TextWithLink([self.render(o) for o in paragraph.children])
+            rr = [TextWithLink([self.render(o) for o in paragraph.inline])]
+            for inl in paragraph.inner:
+                rr.append(self.render(inl))
+            return urwid.Pile(rr)
         except Exception:
             raise ValueError(cc, rr)
 
@@ -423,14 +435,37 @@ class Renderer:
             blank,
         ]
 
-    def render_Fig(self, code):
+    def render_Fig(self, fig):
+        def show_fig(name):
+            cand = next(ingest_dir.glob(f"*/*/assets/{name}"))
+            import subprocess
+
+            subprocess.Popen(
+                ["qlmanage", "-p", cand],
+                stdout=subprocess.DEVNULL,
+                stderr=subprocess.DEVNULL,
+            )
+
+        if sys.platform == "darwin":
+
+            def _cb():
+                show_fig(fig.value)
+
+            msg = "Open with quicklook"
+        else:
+
+            def _cb():
+                None
+
+            msg = "Open in separate window (Not implemented on this platform)"
+
         return TextWithLink(
             [
                 ("", "Figure not available in terminal : "),
                 Link(
                     "verbatim",
-                    "Open in os window",
-                    lambda: self.cb("Not Implemented"),
+                    msg,
+                    _cb,
                 ),
             ]
         )
@@ -552,6 +587,10 @@ def main(qualname: str):
             doc.append(blank)
             doc.append(R.render(blob.example_section_data))
 
+        if blob.item_type and ("module" in blob.item_type):
+            for s in blob.arbitrary:
+                doc.append(R.render(s))
+
         if blob.backrefs:
             doc.append(Text(("section", "Back References")))
             doc.append(Text("All the following items Refer to this page:"))
@@ -565,10 +604,6 @@ def main(qualname: str):
                         left=2,
                     )
                 )
-        if blob.item_type and ("module" in blob.item_type):
-            for s in blob.arbitrary:
-                doc.append(R.render(s))
-
         doc = dedup(doc)
 
         doc.append(blank)
